# Monitoring the Usage and Adoption of SAP LeanIX
### On this page
  * [Introduction to Shared 360](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption#introduction-to-shared-360)
  * [Accessing Shared 360](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption#accessing-shared-360)
  * [Best Practices for Using Shared 360](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption#best-practices-for-using-shared-360)
  * [Frequency of Updates](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption#frequency-of-updates)
  * [Key Sections and Metrics](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption#key-sections-and-metrics)
  * [Workspace Session Tracking](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption#workspace-session-tracking)
  * [Navigation and Usage Tips](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption#navigation-and-usage-tips)


Monitor how your organization uses SAP LeanIX by tracking key metrics in a Shared 360 view powered by Gainsight.
